package VMOMI::HostDasErrorEventHostDasErrorReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
